@@ -19,16 +19,19 @@ package EmailReminder::BirthdayEvent;
 
 use strict;
 use warnings;
-
+use overload '""' => \&str;
 use EmailReminder::Utils;
 use EmailReminder::YearlyEvent;
 
-require Exporter;
-our @ISA = ("EmailReminder::YearlyEvent", "Exporter");
-our @EXPORT = qw(get_th get_email);
+use base qw(EmailReminder::YearlyEvent);
 
-# XML tags, attributes and values
-my $EMAIL_TAG = 'email';
+# XML tags
+__PACKAGE__->mk_accessors(qw(email));
+
+sub str {
+    my ($self) = @_;
+    return $self->get_type . ':' . $self->get_id . ') ' . $self->get_name . ' - ' . $self->get_date;
+}
 
 # Hard-coded value for this event's type (class method)
 sub get_type
@@ -39,38 +42,34 @@ sub get_type
 # Number of fields this event adds to its parent (class method)
 sub get_nb_fields
 {
-    return EmailReminder::YearlyEvent->get_nb_fields() + 1;
+    my ($self) = @_;
+    return $self->SUPER::get_nb_fields() + 1;
 }
 
-sub get_email
+sub valid_email
 {
-    my ($this) = @_;
-    return EmailReminder::Utils::get_node_value($this->{XML_NODE}, $EMAIL_TAG);
-}
-
-sub set_email
-{
-    my ($this, $new_value) = @_;
-    return EmailReminder::Utils::set_node_value($this->{XML_NODE}, $EMAIL_TAG, $new_value);
+    my ($class, $new_value) = @_;
+    # ToDo: do checking on the email address
+    return $new_value;
 }
 
 # Returns the age of the person (starts at 0 years old)
 sub get_occurence
 {
-    my $this = shift;
+    my $self = shift;
 
-    my $age = $this->EmailReminder::YearlyEvent::get_occurence();
+    my $age = $self->EmailReminder::YearlyEvent::get_occurence();
 
     return defined($age) ? ($age - 1) : undef;
 }
 
 sub get_subject
 {
-    my $this = shift;
+    my $self = shift;
 
-    my $name = $this->get_name();
-    my $age  = $this->get_occurence();
-    my $when = $this->{"WHEN"};
+    my $name = $self->get_name();
+    my $age  = $self->get_occurence();
+    my $when = $self->{"WHEN"};
 
     if ($age and $when eq "today") {
         return "$name is now $age";
@@ -82,23 +81,18 @@ sub get_subject
 
 sub get_message_body
 {
-    my $this = shift;
-
-    # destination user
-    my $first_name = shift;
+    my $self = shift;
 
     # birthday person
-    my $name  = $this->get_name();
-    my $email = $this->get_email();
-    my $age   = $this->get_occurence();
-    my $when  = $this->{"WHEN"};
+    my $name  = $self->get_name();
+    my $email = $self->get_email();
+    my $age   = $self->get_occurence();
+    my $when  = $self->{"WHEN"};
     
     my $age_string = $age ? "turning $age" : "getting one year older";
     my $email_message = $email ? "\n\nYou can reach $name at $email." : "";
 
-    my $message = <<MESSAGEEND;
-Hi $first_name,
-
+    my $message = <<"MESSAGEEND";
 I just want to remind you that $name is $age_string $when.$email_message
 MESSAGEEND
 
