@@ -19,7 +19,7 @@ package EmailReminder::MonthlyEvent;
 
 use strict;
 use warnings;
-
+use overload '""' => \&str;
 use Date::Manip;
 use POSIX;
 use Scalar::Util;
@@ -27,13 +27,10 @@ use Scalar::Util;
 use EmailReminder::Event;
 use EmailReminder::Utils;
 
-require Exporter;
-our @ISA    = ("EmailReminder::Event", "Exporter");
-#our @EXPORT = qw(get_name get_current_occurence_date valid_day);
+use base qw(EmailReminder::Event);
 
-# XML tags, attributes and values
-my $DAY_TAG   = 'day';
-my $NAME_TAG  = 'name';
+# XML tags
+__PACKAGE__->mk_accessors(qw(day));
 
 # Global date variables
 my $current_time = ParseDate("now");
@@ -41,6 +38,11 @@ my $current_date = ParseDate(UnixDate($current_time, "\%x"));
 my $current_month = UnixDate($current_time, "\%m");
 my $current_year = UnixDate($current_time, "\%Y");
 
+sub str {
+    my ($self) = @_;
+    return $self->get_type . ':' . $self->get_id . ') ' . $self->get_name . ' - ' . $self->get_day;
+}
+
 # Hard-coded value for this event's type (class method)
 sub get_type
 {
@@ -50,25 +52,13 @@ sub get_type
 # Number of fields this event adds to its parent (class method)
 sub get_nb_fields
 {
-    return EmailReminder::Event->get_nb_fields() + 2;
-}
-
-sub get_name
-{
-    my ($this) = @_;
-    my $name  = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $NAME_TAG);
-    return $name;
-}
-
-sub set_name
-{
-    my ($this, $new_value) = @_;
-    return EmailReminder::Utils::set_node_value($this->{XML_NODE}, $NAME_TAG, $new_value);
+    my ($self) = @_;
+    return $self->SUPER::get_nb_fields() + 2;
 }
 
 sub valid_day
 {
-    my ($new_value) = @_;
+    my ($class, $new_value) = @_;
 
     if (!Scalar::Util::looks_like_number($new_value)) {
         $new_value = 1;
@@ -84,25 +74,12 @@ sub valid_day
     return $new_value;
 }
 
-sub get_day
-{
-    my ($this) = @_;
-    my $day = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $DAY_TAG);
-    return valid_day($day);
-}
-
-sub set_day
-{
-    my ($this, $new_value) = @_;
-    return EmailReminder::Utils::set_node_value($this->{XML_NODE}, $DAY_TAG, valid_day($new_value));
-}
-
 sub get_current_occurence_date
 {
-    my ($this, $modifier) = @_;
+    my ($self, $modifier) = @_;
 
-    my $day = $this->get_day();
-    return undef unless $day;
+    my $day = $self->get_day();
+    return unless $day;
 
     # Set the day of the month where the event occurs, make sure the date is valid
     # (e.g. fix-up for event on the 31st when the month has only 30 days)
@@ -126,24 +103,19 @@ sub get_current_occurence_date
 
 sub get_subject
 {
-    my $this = shift;
-    return $this->get_name();
+    my $self = shift;
+    return $self->get_name();
 }
 
 sub get_message_body
 {
-    my $this = shift;
-
-    # destination user
-    my $first_name = shift;
+    my $self = shift;
 
     # event details
-    my $when      = $this->{"WHEN"};
-    my $name      = $this->get_name();
+    my $when      = $self->{"WHEN"};
+    my $name      = $self->get_name();
     
-    my $message = <<MESSAGEEND;
-Hi $first_name,
-
+    my $message = <<"MESSAGEEND";
 I just want to remind you of the following event $when:
 
 $name
@@ -155,11 +127,11 @@ MESSAGEEND
 # Returns 1 if the event will occur in X days (X is a param)
 sub will_occur
 {
-    my $this = shift;
+    my $self = shift;
     my $modifier = shift;
     
     # Apply the modifier to the event date
-    my $current_occurence_date = $this->get_current_occurence_date($modifier);
+    my $current_occurence_date = $self->get_current_occurence_date($modifier);
     return 0 unless $current_occurence_date;
     
     my $tomorrow = DateCalc($current_date, " + 1 day");
