@@ -91,12 +91,12 @@ sub get_date
 
     # Hack to support events that don't have a starting year
     my $actual_date;
-    if (defined($year)) {
+    if ($year > 0) {
         $self->{"MISSING_YEAR"} = 0;
         $actual_date = UnixDate(ParseDate($year ."-".$month."-".$day),
                                 "\%Y-\%m-\%d");
     }
-    elsif (defined($month) && defined($day)) {
+    elsif (($month > 0) && ($day > 0)) {
         $self->{"MISSING_YEAR"} = 1;
         my $full_date = UnixDate(ParseDate($leap_year."-".$month."-".$day), 
                                  "\%Y-\%m-\%d");
